@@ -329,8 +329,8 @@ png(file=paste0("thirdplot.png" ),width=962,height=1000)
 plotIdiograms(mixChrSize,                         # chr. size data.frame
               mixMarks,                           # data.frame of marks' positions
               dfMarkColor =  mydfMaColor,         # d.f. of mark characteristics
-              origin="b",
-              karHeiSpace=2.2,
+              origin="b",                         # position measured from bottom of chr.
+              karHeiSpace=2.2,                    # karyotype height with spacing included
               
               roundness = 10.5,                   # vertices roundness
               dotRoundCorr = 1.0,                 # correction of roundness of dots and vertices
